AP Bowl 2021 - Part A
-------------------------------------

The following 20 questions are similar to what you might see on the AP CSA exam.  Please answer each to the best of your ability.

Click the **Start** button when you are ready to begin.

.. timed:: ap_bowl_21_timed
   :timelimit: 45

   .. selectquestion:: ap_bowl_21_q1
      :fromid: ap_bowl_2019_q1
      :points: 1

   .. selectquestion:: ap_bowl_21_q2
      :fromid: ap_bowl_2019_q2
      :points: 1

   .. selectquestion:: ap_bowl_21_q3
      :fromid: ap_bowl_2019_q3
      :points: 1

   .. selectquestion:: ap_bowl_21_q4
      :fromid: ap_bowl_2019_q4
      :points: 1

   .. selectquestion:: ap_bowl_21_q5
      :fromid: ap_bowl_2019_q5
      :points: 1

   .. selectquestion:: ap_bowl_21_q6
      :fromid: ap_bowl_2019_q6
      :points: 1

   .. selectquestion:: ap_bowl_21_q7
      :fromid: ap_bowl_2019_q7
      :points: 1

   .. selectquestion:: ap_bowl_21_q8
      :fromid: ap_bowl_2019_q8
      :points: 1

   .. selectquestion:: ap_bowl_21_q9
      :fromid: ap_bowl_2019_q9
      :points: 1

   .. selectquestion:: ap_bowl_21_q10
      :fromid: ap_bowl_2019_q10
      :points: 1

   .. selectquestion:: ap_bowl_21_q11
      :fromid: ap_bowl_2019_q11
      :points: 1

   .. selectquestion:: ap_bowl_21_q12
      :fromid: ap_bowl_2019_q12
      :points: 1

   .. selectquestion:: ap_bowl_21_q13
      :fromid: ap_bowl_2019_q13
      :points: 1

   .. selectquestion:: ap_bowl_21_q14
      :fromid: ap_bowl_2019_q14
      :points: 1

   .. selectquestion:: ap_bowl_21_q15
      :fromid: ap_bowl_2019_q15
      :points: 1

   .. selectquestion:: ap_bowl_21_q16
      :fromid: ap_bowl_2019_q16
      :points: 1

   .. selectquestion:: ap_bowl_21_q17
      :fromid: ap_bowl_2019_q17
      :points: 1

   .. selectquestion:: ap_bowl_21_q18
      :fromid: ap_bowl_2019_q18
      :points: 1

   .. selectquestion:: ap_bowl_21_q19
      :fromid: ap_bowl_2019_q19
      :points: 1

   .. selectquestion:: ap_bowl_21_q20
      :fromid: ap_bowl_2019_q20
      :points: 1
